CmdPlusMode class

The mode in which to run the process.

Annotations
  • @freezed

Constructors

CmdPlusMode.background()
The mode in which to run the process.
const
factory
CmdPlusMode.detached()
The mode in which to run the process.
const
factory
CmdPlusMode.normal()
The mode in which to run the process.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult normal(_Normal value), required TResult background(_Background value), required TResult detached(_Detached value)}) → TResult
inherited
mapOrNull<TResult extends Object?>({TResult? normal(_Normal value)?, TResult? background(_Background value)?, TResult? detached(_Detached value)?}) → TResult?
inherited
maybeMap<TResult extends Object?>({TResult normal(_Normal value)?, TResult background(_Background value)?, TResult detached(_Detached value)?, required TResult orElse()}) → TResult
inherited
maybeWhen<TResult extends Object?>({TResult normal()?, TResult background()?, TResult detached()?, required TResult orElse()}) → TResult
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult normal(), required TResult background(), required TResult detached()}) → TResult
inherited
whenOrNull<TResult extends Object?>({TResult? normal()?, TResult? background()?, TResult? detached()?}) → TResult?
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited