output property

String get output
inherited

The stdout of the process. This can be useful when the result of a command is needed, for example one could run 'pwd' to get the current working directory.

Implementation

String get output => throw _privateConstructorUsedError;