FileFilter class

Filters that can be applied when copying or manipulating files

Implementers
Annotations
  • @freezed

Constructors

FileFilter.replaceInFileContent({required Pattern from, required String replace})
Filters that can be applied when copying or manipulating files
const
factory

Properties

copyWith → $FileFilterCopyWith<FileFilter>
no setterinherited
from Pattern
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
replace String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult replaceInFileContent(ReplaceInFileContentFilter value)}) → TResult
inherited
mapOrNull<TResult extends Object?>({TResult? replaceInFileContent(ReplaceInFileContentFilter value)?}) → TResult?
inherited
maybeMap<TResult extends Object?>({TResult replaceInFileContent(ReplaceInFileContentFilter value)?, required TResult orElse()}) → TResult
inherited
maybeWhen<TResult extends Object?>({TResult replaceInFileContent(Pattern from, String replace)?, required TResult orElse()}) → TResult
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult replaceInFileContent(Pattern from, String replace)}) → TResult
inherited
whenOrNull<TResult extends Object?>({TResult? replaceInFileContent(Pattern from, String replace)?}) → TResult?
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited