CmdPlusMode.background constructor
const
CmdPlusMode.background()
The mode in which to run the process.
CmdPlusMode.background() will print stdout and stderr to the console, but will not be able to asks for user input through stdin.
Implementation
const factory CmdPlusMode.background() = _Background;