CmdPlusResult class
CmdPlusResult is a class representing a result of command execution with CmdPlus
- Annotations
-
- @freezed
Constructors
- CmdPlusResult({required int exitCode, required String output, required String error})
-
CmdPlusResult is a class representing a result of command execution with
CmdPlus
constfactory
Properties
-
copyWith
→ $CmdPlusResultCopyWith<
CmdPlusResult> -
no setterinherited
- error → String
-
The stderr of the process.
no setterinherited
- exitCode → int
-
The exit code of the process.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- output → String
-
The stdout of the process. This can be useful when the result of a
command is needed, for example one could run 'pwd' to get the current
working directory.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited