CmdPlusResult constructor
CmdPlusResult is a class representing a result of command execution with CmdPlus
Implementation
const factory CmdPlusResult({
/// The exit code of the process.
required int exitCode,
/// The [stdout] of the process. This can be useful when the result of a
/// command is needed, for example one could run 'pwd' to get the current
/// working directory.
required String output,
/// The [stderr] of the process.
required String error,
}) = _CmdPlusResult;